/**
 * GMyth Library
 *
 * @file gmyth/gmyth_http.h
 * 
 * @brief <p> GMythHttp library provides a wrapper to access
 * data from the database using http+xml
 *
 * Copyright (C) 2007 INdT - Instituto Nokia de Tecnologia.
 * @author Artur Duque de Souza <artur.souza@indt.org.br>
 *
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef __GMYTH_HTTP_H__
#define __GMYTH_HTTP_H__

#include <glib-object.h>

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdarg.h>
#include <glib.h>
#include <glib/gprintf.h>

#include "gmyth_backendinfo.h"
#include "gmyth_util.h"
#include "gmyth_recprofile.h"

#include <curl/curl.h>
#include <curl/types.h>
#include <curl/easy.h>

G_BEGIN_DECLS

#define MYTH_PORT_STATUS 6544

typedef struct _GMythRecorded_Recording GMythRecorded_Recording;
typedef struct _GMythRecorded_Channel   GMythRecorded_Channel;
typedef struct _GMythRecorded_Program   GMythRecorded_Program;
typedef struct _GMythRecorded   GMythRecorded;
typedef struct _GMythProgram    GMythProgram;
typedef struct _GMythChannel	GMythChannel;
typedef struct _GMythEpg	    GMythEpg;
typedef struct _MemoryStruct    MemoryStruct;

struct _MemoryStruct
{
    char *memory;
    size_t size;
};

struct _GMythProgram
{
  GString* title;
  GString* subtitle;
  GString* catType;
  GString* category;
  gint	repeat;
  GTimeVal* startTime;
  GTimeVal* endTime;
};

struct _GMythChannel
{
  GString* channelName;
  GString* chanNum;
  gint chanId;
  gint callSign;
  GSList* programList;
};

struct _GMythEpg
{
  gint startChanId;
  gint endChanId;
  GString* version;
  gint protoVer;
  gint totalCount;
  gint numOfChannels;
  GTimeVal* asOf;
  GTimeVal* startTime;
  GTimeVal* endTime;
  gint details;
  GSList* channelList;
};


struct _GMythRecorded_Recording
{
  gint dupInType;
  gint dupMethod;
  gint preRollSeconds;
  GString* playGroup;
  gint recPriority;
  GTimeVal* recStartTs;
};


struct _GMythRecorded_Channel
{
  GString* chanFilters;
  GString* channelName;
  gint chanNum;
  gint sourceId;
  gint commFree;
  gint inputId;
  gint chanId;
  gint callSign;
};


struct _GMythRecorded_Program
{
  gint programFlags;
  GString* title;
  gint programId;
  GString* catType;
  GString* category;
  gint seriesId;
  GTimeVal* startTime;
  GTimeVal* endTime;
  GTimeVal* airdate; //?
  GTimeVal* lastModified;
  GString* subTitle;
  gint stars;
  gint repeat;
  gint fileSize;
  GString* hostname;
  GMythRecorded_Channel channel;
  GMythRecorded_Recording recording;
};

struct _GMythRecorded
{
  GString* version;
  gint protoVer;
  gint totalCount;
  GTimeVal* asOf;
  GSList* programList;
};


gchar* gmyth_http_retrieve_setting (GMythBackendInfo *backend_info,\
                                    gchar* key, gchar* hostname);

GMythEpg gmyth_http_retrieve_epg(GMythBackendInfo *backend_info, \
                      GTimeVal* StartTime, GTimeVal* EndTime, \
                      gint StartChanId, gint NumOfChannels, gchar* Details);

GMythRecorded gmyth_http_retrieve_recorded (GMythBackendInfo *backend_info);

GSList* gmyth_http_retrieve_rec_profiles (GMythBackendInfo *backend_info,\
                                         gchar* groupname);

gint gmyth_http_create_rec_profile (GMythBackendInfo *backend_info,\
                                    GMythRecProfile* profile);

gint gmyth_http_del_rec_profile (GMythBackendInfo *backend_info,
                                 gint id);

MemoryStruct gmyth_http_request (GMythBackendInfo *backend_info, GString *command);

G_END_DECLS

#endif /* __GMYTH_HTTP_H__ */
