/**
 * GMyth Library
 * 
 * @file gmyth/gmyth_transcode.h
 * 
 * @brief <p> This file contains the transcode class.
 *
 * Copyright (C) 2007 INdT - Instituto Nokia de Tecnologia.
 * @author Artur Duque de Souza <artur.souza@indt.org.br>
 *
 */
/*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _GMYTH_TRANSCODE_H
#define _GMYTH_TRANSCODE_H

#include <glib.h>
#include <glib-object.h>

#include "gmyth_stringlist.h"
#include "gmyth_backendinfo.h"
#include "gmyth_socket.h"
#include "gmyth_http.h"
#include "gmyth_recprofile.h"

G_BEGIN_DECLS

#define GMYTH_TRANSCODE_TYPE               (gmyth_transcode_get_type ())
#define GMYTH_TRANSCODE(obj)               (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_TRANSCODE_TYPE, GMythTranscode))
#define GMYTH_TRANSCODE_CLASS(klass)       (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_TRANSCODE_TYPE, GMythTranscodeClass))
#define IS_GMYTH_TRANSCODE(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), GMYTH_TRANSCODE_TYPE))
#define IS_GMYTH_TRANSCODE_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), GMYTH_TRANSCODE_TYPE))
#define GMYTH_TRANSCODE_GET_CLASS(obj)     (G_TYPE_INSTANCE_GET_CLASS ((obj), GMYTH_TRANSCODE_TYPE, GMythTranscodeClass))

#define DATE_ISO 0
#define DATE_FILE 1

typedef struct _GMythTranscode         GMythTranscode;
typedef struct _GMythTranscodeClass    GMythTranscodeClass;

struct _GMythTranscodeClass
{
  GObjectClass parent_class;

  /* callbacks */
};

/**
 * The GMythTranscode structure is a class to implement functions
 * related to transcoding.
 */
struct _GMythTranscode
{
    GObject parent;

    gboolean cutlist;
    gboolean output;

    /* private begin */
    GString* output_filename;
    GString* filename;
    GString* profile;
    /* private end */

    GString* starttime;

    gint chanid;

    GMythBackendInfo* backend_info;
};

GType gmyth_transcode_type (void);

GMythTranscode* gmyth_transcode_new (void);

void gmyth_transcode_set_output (GMythTranscode* transcode,
                                 gboolean value, gchar* outputfile);

void gmyth_transcode_set_filename (GMythTranscode* transcode, gchar* file);

G_END_DECLS

#endif /*_GMYTH_TRANSCODE_H*/
